==> nextcloud-app-calendar-1%3A5.2.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_SV.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "Description:" : "Descripción:",
    "Where:" : "Dónde:",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar liga",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "New calendar" : "Nuevo calendario",
    "Export" : "Exportar",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Deck" : "Deck",
    "Hidden" : "Oculto",
    "Share link" : "Compartir liga",
    "can edit" : "puede editar",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Save" : "Guardar",
    "Filename" : "Nombre del archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "or" : "o",
    "Show week numbers" : "Mostrar número de semana",
    "Update" : "Actualizar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "to" : "para",
    "Add" : "Agregar",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Your email address" : "Tu dirección de correo electrónico",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Delete file" : "Borrar archivo",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativo",
    "Attendees" : "Asistentes",
    "All day" : "Todo el día",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "available" : "disponible",
    "Global" : "Global",
    "Subscribe" : "Suscribir",
    "Personal" : "Personal",
    "Details" : "Detalles",
    "Resources" : "Recursos",
    "Close" : "Cerrar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Categories" : "Categorías",
    "User not found" : "No se encontró el usuario"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-app-calendar-1%3A5.3.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_SV.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ha publicado el calendario »%s«",
    "Hello," : "Hola,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Queremos informarte que %s ha publicado el calendario »%s«.",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Calendar" : "Calendario",
    "Confirm" : "Confirmar",
    "Description:" : "Descripción:",
    "Where:" : "Dónde:",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Preview" : "Previsualizar",
    "Copy link" : "Copiar liga",
    "Edit" : "Editar",
    "Delete" : "Borrar",
    "New calendar" : "Nuevo calendario",
    "Export" : "Exportar",
    "Name" : "Nombre",
    "Deleted" : "Borrado",
    "Restore" : "Restaurar",
    "Delete permanently" : "Borrar permanentemente",
    "Deck" : "Deck",
    "Hidden" : "Oculto",
    "Share link" : "Compartir liga",
    "can edit" : "puede editar",
    "Share with users or groups" : "Compartir con otros usuarios o grupos",
    "Save" : "Guardar",
    "Filename" : "Nombre del archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "List view" : "Vista de lista",
    "Actions" : "Acciones",
    "or" : "o",
    "Show week numbers" : "Mostrar número de semana",
    "Update" : "Actualizar",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "to" : "para",
    "Add" : "Agregar",
    "Monday" : "Lunes",
    "Tuesday" : "Martes",
    "Wednesday" : "Miércoles",
    "Thursday" : "Jueves",
    "Friday" : "Viernes",
    "Saturday" : "Sábado",
    "Sunday" : "Domingo",
    "Your email address" : "Tu dirección de correo electrónico",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "days" : "días",
    "weeks" : "semanas",
    "Choose a file to add as attachment" : "Selecciona el archivo a agregar como adjunto",
    "Delete file" : "Borrar archivo",
    "Unknown" : "Desconocido",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Tentative" : "Tentativo",
    "Attendees" : "Asistentes",
    "Repeat" : "Repetir",
    "never" : "nunca",
    "after" : "después",
    "Resources" : "Recursos",
    "available" : "disponible",
    "Global" : "Global",
    "Subscribe" : "Suscribir",
    "Personal" : "Personal",
    "Edit event" : "Editar evento",
    "All day" : "Todo el día",
    "Close" : "Cerrar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Other" : "Otro",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Categories" : "Categorías",
    "User not found" : "No se encontró el usuario",
    "Details" : "Detalles"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
